require 'rbconfig' unless defined? RbConfig
ruby = File.join(RbConfig::CONFIG['bindir'], RbConfig::CONFIG['ruby_install_name'])
system("#{ruby} -Ilib:test test/test-rt2html-lib.rb")
system("#{ruby} -Ilib:test test/test-rtparser.rb")
